package cn.iocoder.yudao.module.inspection.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import cn.iocoder.yudao.module.inspection.entity.InspectionInfo;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Map;


/**
 * 【请填写功能名称】Mapper接口
 *
 * @author ruoyi
 * @date 2023-08-13
 */
@Mapper
public interface InspectionInfoMapper  extends BaseMapper<InspectionInfo>
{
    /**
     * 查询【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public InspectionInfo selectInspectionInfoById(Long id);

    /**
     * 查询【请填写功能名称】列表
     *
     * @param inspectionInfo 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public IPage<InspectionInfo> selectInspectionInfoList(Page<InspectionInfo> page,@Param("vo") InspectionInfo inspectionInfo);

    /**
     * 新增【请填写功能名称】
     *
     * @param inspectionInfo 【请填写功能名称】
     * @return 结果
     */
    public int insertInspectionInfo(InspectionInfo inspectionInfo);

    /**
     * 修改【请填写功能名称】
     *
     * @param inspectionInfo 【请填写功能名称】
     * @return 结果
     */
    public int updateInspectionInfo(InspectionInfo inspectionInfo);

    /**
     * 删除【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteInspectionInfoById(Long id);

    /**
     * 批量删除【请填写功能名称】
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteInspectionInfoByIds(Long[] ids);
    List<InspectionInfo> workOrder(@Param("partnerId") Long partnerId, @Param("carNum")String carNum, @Param("goodsTitle")String goodsTitle
            , @Param("customerSource")String customerSource, @Param("payType")String payType, @Param("startTime")String startTime
            , @Param("roleId") Long roleId, @Param("endTime")String endTime);
    IPage<InspectionInfo> pageWorkOrder(@Param("partnerId") Long partnerId, @Param("carNum")String carNum, @Param("goodsTitle")String goodsTitle
            , @Param("customerSource")String customerSource, @Param("payType")String payType, @Param("startTime")String startTime
            , @Param("roleId") Long roleId, @Param("endTime")String endTime,Page<InspectionInfo> page);

    List<InspectionInfo> delworkOrder(@Param("partnerId") Long partnerId, @Param("carNum")String carNum, @Param("goodsTitle")String goodsTitle
            ,@Param("customerSource")String customerSource,@Param("payType")String payType,@Param("startTime")String startTime
            ,@Param("roleId") Long roleId,@Param("endTime")String endTime);

    IPage<InspectionInfo> pageDelWorkOrder(@Param("partnerId") Long partnerId, @Param("carNum")String carNum, @Param("goodsTitle")String goodsTitle
            , @Param("customerSource")String customerSource, @Param("payType")String payType, @Param("startTime")String startTime
            , @Param("roleId") Long roleId, @Param("endTime")String endTime,Page<InspectionInfo> page);

    Map<String, Object> workOrderData(@Param("partnerId") Long partnerId, @Param("carNum")String carNum, @Param("goodsTitle")String goodsTitle
            , @Param("customerSource")String customerSource, @Param("payType")String payType, @Param("startTime")String startTime
            , @Param("roleId") Long roleId, @Param("endTime")String endTime);


    /**
     * 查询当前用户符合条件的工单
     * @param page
     * @return
     */
    IPage<InspectionInfo> selectByUser(@Param("page") IPage page, @Param("roleIds") List<Long> roleIds,@Param("inspectionInfo") InspectionInfo inspectionInfo);
}
